'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var propTypes = _interopDefault(require('prop-types'));
var Draft = require('draft-js');
var Draft__default = _interopDefault(Draft);
var Axios = _interopDefault(require('axios'));
var draftJsExportHtml = require('draft-js-export-html');
var CodeUtils = _interopDefault(require('draft-js-code'));
var Create = _interopDefault(require('draft-js-plugins-editor'));

/* eslint-disable react/prop-types */

// eslint-disable-next-line react/prop-types
var Image = function Image(_ref) {
  var src = _ref.src;

  if (src) {
    return React__default.createElement('img', { src: src, alt: 'jpg' });
  }
  return null;
};
var Media = function Media(props) {
  var entity = props.contentState.getEntity(props.block.getEntityAt(0));

  var _entity$getData = entity.getData(),
      src = _entity$getData.src;

  var type = entity.getType();

  var media = void 0;

  if (type === 'image') {
    media = React__default.createElement(Image, { src: src });
  }

  return media;
};
var mediaBlockRenderer = (function (block) {
  if (block.getType() === 'atomic') {
    return {
      component: Media,
      editable: false
    };
  }

  return null;
});

/* eslint-disable react/prop-types */

// eslint-disable-next-line react/prop-types
var findImageEntities = function findImageEntities(contentBlock, callback, contentState) {
  contentBlock.findEntityRanges(function (character) {
    var entityKey = character.getEntity();
    return entityKey !== null && contentState.getEntity(entityKey).getType() === 'IMAGE';
  }, callback);
};
var UpdateImage = function UpdateImage(props) {
  var _props$contentState$g2 = props.contentState.getEntity(props.entityKey).getData(),
      src = _props$contentState$g2.src;

  return React__default.createElement('img', { src: src });
};

var editBlock = (function (block) {
  if (block.getType() === 'IMAGE') {
    console.log(block.getType());
    return {
      component: UpdateImage,
      editable: false
    };
  }

  return null;
});

var HEADER_TYPES = [{ id: 1, label: 'None', style: 'unstyled' }, { id: 2, label: 'H1', style: 'header-one' }, { id: 3, label: 'H2', style: 'header-two' }, { id: 4, label: 'H3', style: 'header-three' }, { id: 5, label: 'H4', style: 'header-four' }, { id: 6, label: 'H5', style: 'header-five' }, { id: 7, label: 'H6', style: 'header-six' }];

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};

var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};

var headingDropdown = function (_Component) {
  inherits(headingDropdown, _Component);

  function headingDropdown() {
    classCallCheck(this, headingDropdown);
    return possibleConstructorReturn(this, (headingDropdown.__proto__ || Object.getPrototypeOf(headingDropdown)).apply(this, arguments));
  }

  createClass(headingDropdown, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          active = _props.active,
          onToggle = _props.onToggle,
          headerOptions = _props.headerOptions;

      onToggle = function onToggle(event) {
        var value = event.target.value;

        _this2.props.onToggle(value);
      };

      return React__default.createElement(
        'div',
        { className: 'input-group input-heading' },
        React__default.createElement(
          'div',
          { className: 'input-group-prepend' },
          React__default.createElement(
            'label',
            { htmlFor: 'heading-selector', className: 'input-group-text' },
            React__default.createElement('i', { className: 'fas fa-heading' })
          )
        ),
        React__default.createElement(
          'select',
          {
            value: active,
            onChange: onToggle,
            className: 'custom-select heading',
            id: 'heading-selector'
          },
          React__default.createElement(
            'option',
            { value: '' },
            'Header Levels'
          ),
          headerOptions.map(function (heading, index) {
            return React__default.createElement(
              'option',
              { value: heading.style, key: index },
              heading.label
            );
          })
        ),
        React__default.createElement(
          'div',
          { className: 'input-heading__text' },
          React__default.createElement(
            'ul',
            null,
            headerOptions.map(function (heading, index) {
              return React__default.createElement(
                'li',
                { key: index },
                React__default.createElement(
                  'button',
                  { onClick: function onClick(event) {
                      return onToggle(event);
                    }, value: heading.style },
                  heading.label
                )
              );
            })
          )
        )
      );
    }
  }]);
  return headingDropdown;
}(React.Component);

headingDropdown.propTypes = {
  onToggle: propTypes.func.isRequired,
  headerOptions: propTypes.array.isRequired,
  active: propTypes.string.isRequired
};

var ORDERING = [{
  id: 1,
  label: 'Ul',
  style: 'unordered-list-item',
  icon: 'fas fa-list-ul'
}, {
  id: 2,
  label: 'OL',
  style: 'ordered-list-item',
  icon: 'fas fa-list-ol'
}, {
  id: 3,
  label: 'code',
  style: 'code-block',
  icon: 'fas fa-code'
}, {
  id: 4,
  label: 'blockquote',
  style: 'blockquote',
  icon: 'fas fa-quote-left'
}];

var listOrdering = function (_Component) {
  inherits(listOrdering, _Component);

  function listOrdering() {
    classCallCheck(this, listOrdering);
    return possibleConstructorReturn(this, (listOrdering.__proto__ || Object.getPrototypeOf(listOrdering)).apply(this, arguments));
  }

  createClass(listOrdering, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var onToggle = this.props.onToggle;

      onToggle = function onToggle(value) {
        _this2.props.onToggle(value);
      };
      return React__default.createElement(
        'ul',
        { className: 'editor__toolbar--ordering' },
        ORDERING.map(function (order) {
          return React__default.createElement(
            'li',
            { key: order.id },
            React__default.createElement(
              'button',
              { onClick: function onClick() {
                  return onToggle(order.style);
                }, type: 'button' },
              React__default.createElement('i', { className: order.icon })
            )
          );
        })
      );
    }
  }]);
  return listOrdering;
}(React.Component);

listOrdering.propTypes = {
  onToggle: propTypes.func.isRequired
};

var textStyling = [{
  id: 1,
  label: 'bold',
  style: 'BOLD',
  icon: 'fas fa-bold'
}, {
  id: 2,
  label: 'italic',
  style: 'ITALIC',
  icon: 'fas fa-italic'
}, {
  id: 3,
  label: 'underline',
  style: 'UNDERLINE',
  icon: 'fas fa-underline'
}];

var TextStyler = function (_Component) {
  inherits(TextStyler, _Component);

  function TextStyler() {
    classCallCheck(this, TextStyler);
    return possibleConstructorReturn(this, (TextStyler.__proto__ || Object.getPrototypeOf(TextStyler)).apply(this, arguments));
  }

  createClass(TextStyler, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          editorState = _props.editorState,
          updateState = _props.updateState;


      var applyStyle = function applyStyle(style) {
        updateState(Draft.RichUtils.toggleInlineStyle(editorState, style));
      };
      return React__default.createElement(
        'ul',
        { className: 'editor__toolbar--text' },
        textStyling.map(function (style) {
          return React__default.createElement(
            'li',
            { key: style.id },
            React__default.createElement(
              'button',
              { onClick: function onClick() {
                  return applyStyle(style.style);
                }, type: 'button' },
              React__default.createElement('i', { className: style.icon })
            )
          );
        })
      );
    }
  }]);
  return TextStyler;
}(React.Component);

TextStyler.propTypes = {
  editorState: propTypes.object.isRequired,
  updateState: propTypes.func.isRequired
};

function imageUpload(_ref) {
  var imageUploader = _ref.imageUploader;

  return React__default.createElement(
    'ul',
    { className: 'editor__toolbar--img' },
    React__default.createElement(
      'li',
      null,
      React__default.createElement('input', {
        type: 'file',
        name: 'file',
        id: 'file',
        className: 'file-uploader',
        onChange: imageUploader
      }),
      React__default.createElement(
        'label',
        { htmlFor: 'file' },
        React__default.createElement('i', { className: 'far fa-image' })
      )
    )
  );
}

imageUpload.propTypes = {
  imageUploader: propTypes.func.isRequired
};

var ALIGNMENT = [{
  id: 1,
  label: 'align-left',
  style: 'left',
  icon: 'fas fa-align-left'
}, {
  id: 2,
  label: 'align-center',
  style: 'center',
  icon: 'fas fa-align-center'
}, {
  id: 3,
  label: 'align-right',
  style: 'right',
  icon: 'fas fa-align-right'
}, {
  id: 4,
  label: 'align-justify',
  style: 'justify',
  icon: 'fas fa-align-justify'
}];

var alignment = function (_Component) {
  inherits(alignment, _Component);

  function alignment() {
    classCallCheck(this, alignment);
    return possibleConstructorReturn(this, (alignment.__proto__ || Object.getPrototypeOf(alignment)).apply(this, arguments));
  }

  createClass(alignment, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var onToggle = this.props.onToggle;

      onToggle = function onToggle(value) {
        _this2.props.onToggle(value);
      };
      return React__default.createElement(
        'ul',
        { className: 'editor__toolbar--alignment' },
        ALIGNMENT.map(function (order) {
          return React__default.createElement(
            'li',
            { key: order.id },
            React__default.createElement(
              'button',
              { onClick: function onClick() {
                  return onToggle(order.style);
                }, type: 'button' },
              React__default.createElement('i', { className: order.icon })
            )
          );
        })
      );
    }
  }]);
  return alignment;
}(React.Component);

alignment.propTypes = {
  onToggle: propTypes.func.isRequired
};

var index = function (_Component) {
  inherits(index, _Component);

  function index() {
    classCallCheck(this, index);
    return possibleConstructorReturn(this, (index.__proto__ || Object.getPrototypeOf(index)).apply(this, arguments));
  }

  createClass(index, [{
    key: 'render',
    value: function render() {
      var _props = this.props,
          editorState = _props.editorState,
          onToggle = _props.onToggle,
          updateState = _props.updateState,
          imageUploader = _props.imageUploader;

      var selection = editorState.getSelection();
      var blockType = editorState.getCurrentContent().getBlockForKey(selection.getStartKey()).getType();

      return React__default.createElement(
        'div',
        null,
        React__default.createElement(
          'div',
          { className: 'editor__toolbar' },
          React__default.createElement(headingDropdown, {
            headerOptions: HEADER_TYPES,
            active: blockType,
            onToggle: onToggle
          }),
          React__default.createElement(listOrdering, {
            active: blockType,
            onToggle: onToggle
          }),
          React__default.createElement(TextStyler, {
            updateState: updateState,
            editorState: editorState
          }),
          React__default.createElement(alignment, {
            active: blockType,
            onToggle: onToggle
          }),
          React__default.createElement(imageUpload, {
            imageUploader: imageUploader
          })
        )
      );
    }
  }]);
  return index;
}(React.Component);

index.propTypes = {
  editorState: propTypes.object.isRequired,
  onToggle: propTypes.func.isRequired,
  updateState: propTypes.func.isRequired,
  imageUploader: propTypes.func.isRequired

};

var imageUpload$1 = (function (e) {
  return new Promise(function (resolve, reject) {
    var baseUrl = 'https://api.cloudinary.com/v1_1/dkqqm2qwn/upload';
    var basePreset = 'n9dlfrxu';
    var imageFile = e.target.files[0];
    // eslint-disable-next-line no-undef
    var formData = new FormData();
    formData.append('file', imageFile);
    formData.append('upload_preset', basePreset);

    Axios.post(baseUrl, formData, {
      headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
    }).then(function (res) {
      resolve(res.data.secure_url);
    }).catch(function (err) {
      return reject(err);
    });
  });
});

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css = ".styles_DraftEditor-root__121YA {\n  min-height: 200px;\n}\n\n.styles_DraftEditor-editorContainer__33NMd {\n  margin: 10px 10px 0 10px;\n}\n\n.styles_DraftEditor-editorContainer__33NMd .styles_public-DraftEditor-content__3Robi figure {\n  text-align: center;\n}\n\n.styles_DraftEditor-editorContainer__33NMd .styles_public-DraftEditor-content__3Robi figure img {\n  padding: 10px;\n  width: 65%;\n}\n\n.styles_DraftEditor-editorContainer__33NMd .styles_public-DraftEditor-content__3Robi pre {\n  background-color: rgba(0, 0, 0, 0.05);\n  font-family: 'Inconsolata', 'Menlo', 'Consolas', monospace;\n  font-size: 16px;\n  margin-bottom: 20px;\n}\n\n.styles_DraftEditor-editorContainer__33NMd .styles_public-DraftEditor-content__3Robi h1 {\n  font-weight: 600;\n  text-align: center;\n}\n\n.styles_editor__9lmdU {\n  position: relative;\n  border: 1px solid #ced4da;\n}\n\n.styles_editor__toolbar__WgVNe {\n  height: 70px;\n  width: 100%;\n  border-bottom: 1px solid #ced4da;\n}\n\n.styles_editor__toolbar__WgVNe ul {\n  width: 250px;\n  position: absolute;\n  margin: 2% 0 0 12%;\n  list-style: none;\n}\n\n.styles_editor__toolbar__WgVNe ul li {\n  display: inline-block;\n  cursor: pointer;\n}\n\n.styles_editor__toolbar__WgVNe ul li:not(:first-child) {\n  margin-left: 12%;\n}\n\n.styles_editor__toolbar__WgVNe ul li:hover i {\n  color: #ced4da;\n}\n\n.styles_editor__toolbar__WgVNe ul button {\n  border: none;\n  background-color: #ffffff;\n  outline: none;\n}\n\n.styles_editor__toolbar--ordering__3MubT {\n  left: 20%;\n}\n\n.styles_editor__toolbar--alignment__3qhxb {\n  left: 43%;\n}\n\n.styles_editor__toolbar--img__3Pl4d {\n  left: 65%;\n}\n\n.styles_editor__toolbar--img__3Pl4d input[type='file'].styles_file-uploader__14hbs {\n  display: none;\n  cursor: pointer;\n}\n\n.styles_editor__toolbar--img__3Pl4d li {\n  width: 26.1px;\n  height: 26.1px;\n  z-index: -1;\n  cursor: pointer;\n}\n\n.styles_input-group__I4u01 {\n  width: 13%;\n  margin-top: 1.5% !important;\n  margin-left: 1% !important;\n  position: absolute;\n}\n\n.styles_RichEditor-blockquote__3WOx9 {\n  background: #f9f9f9;\n  border-left: 10px solid #ccc;\n  margin: 1.5em 10px;\n  padding: 0.5em 10px;\n  quotes: '\\201C' '\\201D' '\\2018' '\\2019';\n}\n\n.styles_RichEditor-blockquote__3WOx9::before {\n  color: #ccc;\n  content: open-quote;\n  font-size: 4em;\n  line-height: 0.1em;\n  margin-right: 0.25em;\n  vertical-align: -0.4em;\n}\n";
styleInject(css);

var SimplexEditor = function (_React$Component) {
  inherits(SimplexEditor, _React$Component);

  function SimplexEditor(props) {
    classCallCheck(this, SimplexEditor);

    var _this = possibleConstructorReturn(this, (SimplexEditor.__proto__ || Object.getPrototypeOf(SimplexEditor)).call(this));

    _this.onChange = function (editorState) {
      _this.setState({ editorState: editorState });
      var rawHtml = draftJsExportHtml.stateToHTML(editorState.getCurrentContent());
      // eslint-disable-next-line react/prop-types
      _this.props.getArticle(rawHtml);
    };

    _this.handleKeyCommand = function (command) {
      var newState = Draft.RichUtils.handleKeyCommand(_this.state.editorState, command);
      if (newState) {
        _this.onChange(newState);
        return 'handled';
      }
      return 'not-handled';
    };

    _this.focus = function () {
      return _this.refs.editor.focus();
    };

    _this.onURLChange = function (e) {
      return _this.setState({ urlValue: e.target.value });
    };

    _this.onAddImage = function (imageUrl) {
      var isEdit = _this.state.isEdit;

      var imageRender = isEdit ? 'IMAGE' : 'image';
      var editorState = _this.state.editorState;

      var contentState = editorState.getCurrentContent();
      var contentStateWithEntity = contentState.createEntity(imageRender, 'IMMUTABLE', { src: imageUrl });
      var entityKey = contentStateWithEntity.getLastCreatedEntityKey();
      var newEditorState = Draft.EditorState.set(editorState, { currentContent: contentStateWithEntity }, 'create-entity');
      _this.setState({
        editorState: Draft.AtomicBlockUtils.insertAtomicBlock(newEditorState, entityKey, ' ')
      });
    };

    _this.onUnderlineClick = function () {
      _this.onChange(Draft.RichUtils.toggleInlineStyle(_this.state.editorState, 'UNDERLINE'));
    };

    _this.onBoldClick = function () {
      _this.onChange(Draft.RichUtils.toggleInlineStyle(_this.state.editorState, 'BOLD'));
    };

    _this.onItalicClick = function () {
      _this.onChange(Draft.RichUtils.toggleInlineStyle(_this.state.editorState, 'ITALIC'));
    };

    _this.toggleBlockType = function (blockType) {
      _this.onChange(Draft.RichUtils.toggleBlockType(_this.state.editorState, blockType));
    };

    _this.getBlockStyle = function (block) {
      switch (block.getType()) {
        case 'blockquote':
          return 'RichEditor-blockquote';
        case 'left':
          return 'text-left';
        case 'center':
          return 'text-center';
        case 'right':
          return 'text-right';
        case 'justify':
          return 'text-justify';
        default:
          return null;
      }
    };

    _this.updateState = function (editorState) {
      _this.setState({ editorState: editorState });
    };

    _this.imageUrlGet = function (e) {
      imageUpload$1(e).then(function (res) {
        _this.onAddImage(res);
      });
    };

    _this.handleKeyCommand = function (command) {
      var editorState = _this.state.editorState;

      var newState = void 0;

      if (CodeUtils.hasSelectionInBlock(editorState)) {
        newState = CodeUtils.handleKeyCommand(editorState, command);
      }

      if (!newState) {
        newState = Draft.RichUtils.handleKeyCommand(editorState, command);
      }

      if (newState) {
        _this.onChange(newState);
        return 'handled';
      }
      return 'not-handled';
    };

    _this.keyBindingFn = function (evt) {
      var editorState = _this.state.editorState;

      if (!CodeUtils.hasSelectionInBlock(editorState)) {
        return Draft__default.getDefaultKeyBinding(evt);
      }

      var command = CodeUtils.getKeyBinding(evt);

      return command || Draft__default.getDefaultKeyBinding(evt);
    };

    _this.handleReturn = function (evt) {
      var editorState = _this.state.editorState;

      if (!CodeUtils.hasSelectionInBlock(editorState)) return 'not-handled';

      _this.onChange(CodeUtils.handleReturn(evt, editorState));
      return 'handled';
    };

    _this.onTab = function (evt) {
      var editorState = _this.state.editorState;

      if (!CodeUtils.hasSelectionInBlock(editorState)) return 'not-handled';

      _this.onChange(CodeUtils.onTab(evt, editorState));
      return 'handled';
    };

    _this.state = {
      editorState: null,
      isEdit: true
    };
    var decorator = new Draft.CompositeDecorator([{
      strategy: findImageEntities,
      component: UpdateImage
    }]);
    var content = props.content;

    if (content) {
      console.log('create');
      var blockFromHtml = Draft.convertFromHTML(content);
      var contentBlocks = blockFromHtml.contentBlocks,
          entintyMap = blockFromHtml.entintyMap;

      var contentState = Draft.ContentState.createFromBlockArray(contentBlocks, entintyMap);
      var initialContent = Draft.EditorState.createWithContent(contentState, decorator);
      _this.state = { editorState: initialContent, isEdit: true };
    } else {
      console.log('editor');
      _this.state = { editorState: Draft.EditorState.createEmpty(), isEdit: false };
    }
    return _this;
  }

  createClass(SimplexEditor, [{
    key: 'render',
    value: function render() {
      var _state = this.state,
          editorState = _state.editorState,
          isEdit = _state.isEdit;

      return React__default.createElement(
        'div',
        null,
        React__default.createElement(
          'div',
          { className: 'editor' },
          React__default.createElement(
            'div',
            { className: 'editor__box' },
            React__default.createElement(index, {
              editorState: editorState,
              updateState: this.updateState,
              onToggle: this.toggleBlockType,
              imageUploader: this.imageUrlGet
            }),
            isEdit ? React__default.createElement(Draft.Editor, {
              blockStyleFn: this.getBlockStyle,
              blockRendererFn: editBlock,
              editorState: editorState,
              onChange: this.onChange,
              plugins: this.plugins,
              keyBindingFn: this.keyBindingFn,
              handleKeyCommand: this.handleKeyCommand,
              handleReturn: this.handleReturn,
              onTab: this.onTab,
              refs: 'editor'
            }) : React__default.createElement(Create, {
              blockStyleFn: this.getBlockStyle,
              blockRendererFn: mediaBlockRenderer,
              editorState: editorState,
              onChange: this.onChange,
              plugins: this.plugins,
              keyBindingFn: this.keyBindingFn,
              handleKeyCommand: this.handleKeyCommand,
              handleReturn: this.handleReturn,
              onTab: this.onTab,
              refs: 'editor'
            })
          )
        )
      );
    }
  }]);
  return SimplexEditor;
}(React__default.Component);

SimplexEditor.propTypes = {
  getArticle: propTypes.func.isRequired,
  content: propTypes.string
};

module.exports = SimplexEditor;
//# sourceMappingURL=index.js.map
